==> haskell-skylighting-format-ansi-0.1-260-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-321zcznIpJn4bX3j39yC0u
key:                  skylighting-format-ansi-0.1-321zcznIpJn4bX3j39yC0u
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  90b076faeb561c5592c61b66e5f3deab
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-321zcznIpJn4bX3j39yC0u
depends:
    ansi-terminal-1.0.2-vFVvoY6zrCCEYOqozRT68 base-4.17.2.1
    binary-0.8.9.1 colour-2.3.6-LEHIraXdsTIL7HQceHTRk6 containers-0.6.7
    skylighting-core-0.14.2-U7pOWmWOvlKkrG8v4Wz4f text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-261-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-AQxhYmbdc07IzeA8AEVNrO
key:                  skylighting-format-ansi-0.1-AQxhYmbdc07IzeA8AEVNrO
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  a93439786b9927f6758c64a77e5a0def
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-AQxhYmbdc07IzeA8AEVNrO
depends:
    ansi-terminal-1.0.2-FTkVGNDxEfy5jKOkYDwQmU base-4.17.2.1
    binary-0.8.9.1 colour-2.3.6-CLY4OzhkO79pVufYt5HDp containers-0.6.7
    skylighting-core-0.14.2-28LeJNz0dYZ33au9ZJrg74 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
